@@ -93,12 +93,12 @@ char	TerminateClose = 0;
 int	Interrupt = 0;
 
 struct FDDescriptor *FDD = NULL;
-short MaxFD = 0;
-short nFDsInUse = 0;
+int MaxFD = 0;
+int nFDsInUse = 0;
 fd_set ReadDescriptors;
 fd_set WriteDescriptors;
 fd_set BlockedReadDescriptors;
-short HighestFD;
+int HighestFD;
 
 short	debuglevel = 0;
 short	Verbose = 0;
@@ -131,11 +131,11 @@ static CMDResult   CMDQuit	(int argc, char **argv);
 static CMDResult   CMDHelp	(int argc, char **argv);
 
 typedef struct _CMDFunc {
-    char	*name;
-    char	*alias;
+    const char	*name;
+    const char	*alias;
     CMDResult	(*func)(int argc, char **argv);
-    char	*usage;
-    char	*help;
+    const char	*usage;
+    const char	*help;
 } CMDFuncRec;
 typedef const CMDFuncRec *CMDFuncPtr;
 
@@ -489,7 +489,7 @@ CMDBreak (
 	*minorname = ':'; /* restore string for error message */
 	return CMDSyntax;
       }
-      bp = (BP *) malloc (sizeof (BP));
+      bp = malloc (sizeof (BP));
       bp->number = ++breakPointNumber;
       bp->request = request;
       bp->minorop = minorop;
@@ -633,6 +633,11 @@ CMDStep (
     return CMDProceed;
 }
 
+#ifdef __SUNPRO_C
+/* prevent "Function has no return statement" error for CMDQuit */
+#pragma does_not_return(exit)
+#endif
+
 static CMDResult
 CMDQuit (
     int argc,
@@ -748,7 +753,7 @@ ScanArgs (
 	      	4 - I/O, connections
 	      	8 - Scope internals
 	      	16 - Message protocol
-		32 - 64 - malloc
+		32 - 64 - was malloc, now unused
 		128 - 256 - really low level
 	    */
 	  case 'D':
@@ -933,7 +938,7 @@ SetUpStdin (void)
 */
 
 static long clientNumber = 0;
-struct fdinfo   FDinfo[StaticMaxFD];
+struct fdinfo   *FDinfo;
 
 void
 SetUpPair(
@@ -946,6 +951,12 @@ SetUpPair(
       FDinfo[client].Server = false;
       FDinfo[client].pair = server;
       FDinfo[client].ClientNumber = clientNumber;
+      if (FDinfo[client].buffer == NULL)
+	{
+	  FDinfo[client].buffer = calloc(1, BUFFER_SIZE);
+	  if (FDinfo[client].buffer == NULL)
+	    panic("unable to allocate client buffer");
+	}
       FDinfo[client].bufcount = 0;
       FDinfo[client].buflimit = -1;
       FDinfo[client].bufdelivered = 0;
@@ -954,6 +965,12 @@ SetUpPair(
 	  FDinfo[server].Server = true;
 	  FDinfo[server].pair = client;
 	  FDinfo[server].ClientNumber = FDinfo[client].ClientNumber;
+	  if (FDinfo[server].buffer == NULL)
+	    {
+	      FDinfo[server].buffer = calloc(1, BUFFER_SIZE);
+	      if (FDinfo[server].buffer == NULL)
+		panic("unable to allocate server buffer");
+	    }
 	  FDinfo[server].bufcount = 0;
 	  FDinfo[server].buflimit = -1;
 	  FDinfo[server].bufdelivered = 0;
@@ -973,12 +990,16 @@ ResetPair (
 {
   if (client >= 0)
   {
+    free(FDinfo[client].buffer);
+    FDinfo[client].buffer = NULL;
     FDinfo[client].bufcount = 0;
     FDinfo[client].buflimit = -1;
     FDinfo[client].bufdelivered = 0;
   }
   if (server >= 0)
   {
+    free(FDinfo[server].buffer);
+    FDinfo[server].buffer = NULL;
     FDinfo[server].bufcount = 0;
     FDinfo[server].buflimit = -1;
     FDinfo[server].bufdelivered = 0;
@@ -1034,7 +1055,7 @@ ServerHalf (
   return(FDinfo[fd].pair);
 }
 
-char *
+const char *
 ClientName (
     FD fd)
 {
@@ -1042,7 +1063,7 @@ ClientName (
 
   if (clientNumber <= 1)
     return("");
-  (void)sprintf(name, " %ld", FDinfo[fd].ClientNumber);
+  (void)sprintf(name, " %d", FDinfo[fd].ClientNumber);
   return(name);
 }
 
