@@ -107,9 +107,9 @@ extern char AudioServerHostName[MAXHOSTNAMELEN];
 struct fdinfo
 {
   Boolean Server;
-  long    ClientNumber;
+  int     ClientNumber;
   FD	  pair;
-  unsigned char	  buffer[BUFFER_SIZE];
+  unsigned char	  *buffer;
   int	  bufcount;
   int	  bufstart;
   int	  buflimit;	/* limited writes */
@@ -117,7 +117,7 @@ struct fdinfo
   Boolean writeblocked;
 };
 
-extern struct fdinfo   FDinfo[StaticMaxFD];
+extern struct fdinfo   *FDinfo;
 extern int littleEndian;
 extern char HandleSIGUSR1;
 extern char Leader[];
