@@ -53,7 +53,7 @@
 struct TypeDef  TD[MaxTypes];
 unsigned char    RBf[2];
 unsigned char    SBf[4];
-struct ConnState    CS[StaticMaxFD];
+struct ConnState    *CS;
 
 /* ************************************************************ */
 /*								*/
@@ -212,11 +212,9 @@ SaveBytes (
     {
       /* not enough room so far; malloc more space and copy */
       long    SizeofNewBytes = (CS[fd].NumberofSavedBytes + n + 1);
-      unsigned char   *NewBytes = (unsigned char *)Malloc (SizeofNewBytes);
-      bcopy(/* from  */(char *)CS[fd].SavedBytes,
-	    /* to    */(char *)NewBytes,
-	    /* count */(int)CS[fd].SizeofSavedBytes);
-      Free((char *)CS[fd].SavedBytes);
+      unsigned char   *NewBytes = realloc (CS[fd].SavedBytes, SizeofNewBytes);
+      if (NewBytes == NULL)
+	panic("Can't allocate memory for SavedBytes");
       CS[fd].SavedBytes = NewBytes;
       CS[fd].SizeofSavedBytes = SizeofNewBytes;
     }
@@ -471,7 +469,7 @@ StopClientConnection (
   /* when a new connection is stopped, discard the old buffer */
 
   if (CS[fd].SizeofSavedBytes > 0)
-    Free((char*)CS[fd].SavedBytes);
+    free(CS[fd].SavedBytes);
 }
 
 long
@@ -622,7 +620,7 @@ StopServerConnection (
   /* when a new connection is stopped, discard the old buffer */
 
   if (CS[fd].SizeofSavedBytes > 0)
-    Free((char *)CS[fd].SavedBytes);
+    free(CS[fd].SavedBytes);
 }
 
 long
