@@ -263,8 +263,6 @@
 
 #define MaxTypes 256
 
-extern char ScopeEnabled;
-
 /* ************************************************************ */
 /*								*/
 /*								*/
@@ -508,7 +506,7 @@ struct ConnState
     long    SequenceNumber;
 };
 
-extern struct ConnState    CS[StaticMaxFD];
+extern struct ConnState    *CS;
 
 typedef struct _Value {
     struct _Value   *next;
